PitchClass class

Combination of note name and accidental (independent of octave).

Implemented types

Constructors

PitchClass(int setNumber)
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setNumber int
The set number of this pitch class (starting from 0).
final

Methods

compareTo(PitchClass other) int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator <(PitchClass other) bool
operator <=(PitchClass other) bool
operator ==(Object other) bool
The equality operator.
override
operator >(PitchClass other) bool
operator >=(PitchClass other) bool

Constants

aFlat → const PitchClass
aNatural → const PitchClass
aSharp → const PitchClass
bFlat → const PitchClass
bNatural → const PitchClass
cNatural → const PitchClass
cSharp → const PitchClass
dFlat → const PitchClass
dNatural → const PitchClass
dSharp → const PitchClass
eFlat → const PitchClass
eNatural → const PitchClass
fNatural → const PitchClass
fSharp → const PitchClass
gFlat → const PitchClass
gNatural → const PitchClass
gSharp → const PitchClass