identity property
The numeric identity of the scale from its binary representation, see https://ianring.com/musictheory/scales/ for more details.
Implementation
final int identity;
The numeric identity of the scale from its binary representation, see https://ianring.com/musictheory/scales/ for more details.
final int identity;