Scale class
Constructors
- Scale({required PitchClass tonic, required int identity})
- Scale.blues(PitchClass tonic)
-
const
- Scale.chromatic(PitchClass tonic)
-
const
- Scale.harmonicMajor(PitchClass tonic)
-
const
- Scale.harmonicMinor(PitchClass tonic)
-
const
- Scale.major(PitchClass tonic)
-
const
- Scale.majorPentatonic(PitchClass tonic)
-
const
- Scale.melodicMinor(PitchClass tonic)
-
const
- Scale.minorPentatonic(PitchClass tonic)
-
const
- Scale.naturalMinor(PitchClass tonic)
-
const
- Scale.octatonic(PitchClass tonic)
-
const
- Scale.wholetone(PitchClass tonic)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- identity → int
-
The numeric identity of the scale from its binary representation, see
https://ianring.com/musictheory/scales/ for more details.
final
- modeCount → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tonic → PitchClass
-
The starting pitch class for the scale, for example "D#"
final
Methods
-
mode(
int modeNumber) → Scale -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toList(
) → List< PitchClass> -
toSet(
) → Set< PitchClass> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
int scaleDegree) → PitchClass